From c70566e01ba2ed8a0e7089b7e981d7800d42ea99 Mon Sep 17 00:00:00 2001
From: Wang Xingchao <xingchao.wang@linux.intel.com>
Date: Thu, 11 Jul 2013 18:54:20 -0400
Subject: [PATCH] ALSA: hda - Enable WAKEEN for codecs blindly for test

As HDA Spec(4.5.9.2) said, WAKEEN bits enable waking up capability
when controller in D3 or system in S3. This patch enabled all WAKEEN
bits blindly for test.

Signed-off-by: Wang Xingchao <xingchao.wang@linux.intel.com>
---
 sound/pci/hda/hda_intel.c | 11 ++++++++++-
 1 file changed, 10 insertions(+), 1 deletion(-)

diff --git a/sound/pci/hda/hda_intel.c b/sound/pci/hda/hda_intel.c
index cc548e00..f9a2518 100644
--- a/sound/pci/hda/hda_intel.c
+++ b/sound/pci/hda/hda_intel.c
@@ -1290,6 +1290,9 @@ static void azx_init_chip(struct azx *chip, int full_reset)
 	azx_writel(chip, DPLBASE, (u32)chip->posbuf.addr);
 	azx_writel(chip, DPUBASE, upper_32_bits(chip->posbuf.addr));
 
+	/* enable controller Wake Up event*/
+	azx_writeb(chip, WAKEEN, azx_readb(chip, WAKEEN) |
+		  0xFF);
 	chip->initialized = 1;
 }
 
@@ -1374,7 +1377,7 @@ static irqreturn_t azx_interrupt(int irq, void *dev_id)
 {
 	struct azx *chip = dev_id;
 	struct azx_dev *azx_dev;
-	u32 status;
+	u32 status, event;
 	u8 sd_status;
 	int i, ok;
 
@@ -1383,6 +1386,12 @@ static irqreturn_t azx_interrupt(int irq, void *dev_id)
 		return IRQ_NONE;
 #endif
 
+	status = azx_readb(chip, STATESTS);
+	if (status) {
+		event = azx_readb(chip, WAKEEN);
+		snd_printdd("wake up event %x status %x\n", event, status);
+	}
+
 	spin_lock(&chip->reg_lock);
 
 	if (chip->disabled) {
-- 
1.8.3.2

